import { createComponentVNode, normalizeProps } from 'inferno';

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import classNames from 'classnames';
import { mapToCssModules } from './utils';
import { Popper } from 'inferno-popper';

var defaultProps = {
  tag: 'div',
  flip: true
};

var noFlipModifier = { flip: { enabled: false } };

var DropdownMenu = function DropdownMenu(props, context) {
  var className = props.className,
      cssModule = props.cssModule,
      right = props.right,
      tag = props.tag,
      flip = props.flip,
      attrs = _objectWithoutProperties(props, ['className', 'cssModule', 'right', 'tag', 'flip']);

  var position1 = context.dropup ? 'top' : 'bottom';
  var position2 = right ? 'end' : 'start';
  var classes = mapToCssModules(classNames(className, 'dropdown-menu', {
    'dropdown-menu-right': right,
    show: context.isOpen
  }), cssModule);

  attrs.placement = position1 + '-' + position2;

  return normalizeProps(createComponentVNode(2, Popper, Object.assign({
    'tabIndex': '-1',
    'role': 'menu'
  }, attrs, {
    'component': tag,
    'aria-hidden': !context.isOpen,
    'className': classes,
    'modifiers': !flip ? noFlipModifier : undefined
  })));
};

DropdownMenu.defaultProps = defaultProps;

export default DropdownMenu;