import { createVNode } from 'inferno';

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import classNames from 'classnames';
import { createElement } from 'inferno-create-element';
import { mapToCssModules } from './utils';

var defaultProps = {
  tag: 'a'
};

var PaginationLink = function PaginationLink(props) {
  var className = props.className,
      cssModule = props.cssModule,
      next = props.next,
      previous = props.previous,
      Tag = props.tag,
      attributes = _objectWithoutProperties(props, ['className', 'cssModule', 'next', 'previous', 'tag']);

  var classes = mapToCssModules(classNames(className, 'page-link'), cssModule);

  var defaultAriaLabel = void 0;
  if (previous) {
    defaultAriaLabel = 'Previous';
  } else if (next) {
    defaultAriaLabel = 'Next';
  }
  var ariaLabel = props['aria-label'] || defaultAriaLabel;

  var defaultCaret = void 0;
  if (previous) {
    defaultCaret = '\xAB';
  } else if (next) {
    defaultCaret = '\xBB';
  }

  var children = props.children;
  if (previous || next) {
    children = [createVNode(1, 'span', null, children || defaultCaret, 0, {
      'aria-hidden': 'true'
    }, 'caret'), createVNode(1, 'span', 'sr-only', ariaLabel, 0, null, 'sr')];
  }

  Object.assign(attributes, {
    'aria-label': ariaLabel,
    className: classes
  });

  return createElement(Tag, attributes, children);
};

PaginationLink.defaultProps = defaultProps;

export default PaginationLink;